@@ -1,6 +1,6 @@
 package Business::OnlinePayment;
 
-# $Id: OnlinePayment.pm,v 1.8 1999/10/10 05:47:41 robobob Exp $
+# $Id: OnlinePayment.pm,v 1.5 1999/07/28 01:01:39 robobob Exp $
 
 use strict;
 use vars qw($VERSION @ISA @EXPORT @EXPORT_OK $AUTOLOAD);
@@ -11,8 +11,7 @@ require Exporter;
 @ISA = qw(Exporter AutoLoader);
 @EXPORT = qw();
 @EXPORT_OK = qw();
-$VERSION = do { my @r=(q$Revision: 1.8 $=~/\d+/g);sprintf "%d."."%02d"x$#r,@r};
-
+( $VERSION ) = '$Revision: 1.5 $ ' =~ /\$Revision:\s+([^\s]+)/;
 use Carp();
 
 my %fields = (
@@ -70,23 +69,14 @@ sub content {
 }
 
 sub required_fields {
-    my($self,@fields) = @_;
+    my($self,%fields) = @_;
 
     my %content = $self->content();
-    foreach(@fields) {
+    foreach(%fields) {
         Carp::croak("missing required field $_") unless exists $content{$_};
     }
 }
 
-sub get_fields {
-    my($self,@fields) = @_;
-
-    my %content = $self->content();
-    my %new = ();
-    foreach(@fields) { $new{$_} = $content{$_}; }
-    return %new;
-}
-
 sub remap_fields {
     my($self,%map) = @_;
 
@@ -221,22 +211,6 @@ The customers state (your processor may not require this unless you are requirin
 
 The customers zip code (your processor may not require this unless you are requiring AVS Verification).
 
-=item * country
-
-Customer's country.
-
-=item * phone
-
-Customer's phone number.
-
-=item * fax
-
-Customer's fax number.
-
-=item * email
-
-Customer's email address.
-
 =item * card_number
 
 Credit card number (obviously not required for non-credit card transactions).
@@ -245,18 +219,6 @@ Credit card number (obviously not required for non-credit card transactions).
 
 Credit card expiration (obviously not required for non-credit card transactions).
 
-=item * account_number
-
-Bank account number for electronic checks or electronic funds transfer.
-
-=item * routing_code
-
-Bank's routing code for electronic checks or electronic funds transfer.
-
-=item * bank_name
-
-Bank's name for electronic checks or electronic funds transfer.
-
 =back
 
 =head2 submit();
